# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import (
    StyleGuide,
    StyleGuideCreateResponse,
    StyleGuideUpdateResponse,
    StyleGuideRetrieveResponse,
)
from tests.utils import assert_matches_type
from avido.pagination import SyncOffsetPagination, AsyncOffsetPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestStyleGuides:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        style_guide = client.style_guides.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )
        assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.style_guides.with_raw_response.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = response.parse()
        assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.style_guides.with_streaming_response.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = response.parse()
            assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Avido) -> None:
        style_guide = client.style_guides.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Avido) -> None:
        response = client.style_guides.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = response.parse()
        assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Avido) -> None:
        with client.style_guides.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = response.parse()
            assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.style_guides.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: Avido) -> None:
        style_guide = client.style_guides.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )
        assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Avido) -> None:
        response = client.style_guides.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = response.parse()
        assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Avido) -> None:
        with client.style_guides.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = response.parse()
            assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.style_guides.with_raw_response.update(
                id="",
                content=[
                    {
                        "content": "Use professional and clear language",
                        "heading": "Tone",
                    }
                ],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Avido) -> None:
        style_guide = client.style_guides.list()
        assert_matches_type(SyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Avido) -> None:
        style_guide = client.style_guides.list(
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            skip=0,
        )
        assert_matches_type(SyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Avido) -> None:
        response = client.style_guides.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = response.parse()
        assert_matches_type(SyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Avido) -> None:
        with client.style_guides.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = response.parse()
            assert_matches_type(SyncOffsetPagination[StyleGuide], style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncStyleGuides:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        style_guide = await async_client.style_guides.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )
        assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.style_guides.with_raw_response.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = await response.parse()
        assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.style_guides.with_streaming_response.create(
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = await response.parse()
            assert_matches_type(StyleGuideCreateResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAvido) -> None:
        style_guide = await async_client.style_guides.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAvido) -> None:
        response = await async_client.style_guides.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = await response.parse()
        assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAvido) -> None:
        async with async_client.style_guides.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = await response.parse()
            assert_matches_type(StyleGuideRetrieveResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.style_guides.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncAvido) -> None:
        style_guide = await async_client.style_guides.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )
        assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncAvido) -> None:
        response = await async_client.style_guides.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = await response.parse()
        assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncAvido) -> None:
        async with async_client.style_guides.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            content=[
                {
                    "content": "Use professional and clear language",
                    "heading": "Tone",
                }
            ],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = await response.parse()
            assert_matches_type(StyleGuideUpdateResponse, style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.style_guides.with_raw_response.update(
                id="",
                content=[
                    {
                        "content": "Use professional and clear language",
                        "heading": "Tone",
                    }
                ],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAvido) -> None:
        style_guide = await async_client.style_guides.list()
        assert_matches_type(AsyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAvido) -> None:
        style_guide = await async_client.style_guides.list(
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            skip=0,
        )
        assert_matches_type(AsyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAvido) -> None:
        response = await async_client.style_guides.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        style_guide = await response.parse()
        assert_matches_type(AsyncOffsetPagination[StyleGuide], style_guide, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAvido) -> None:
        async with async_client.style_guides.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            style_guide = await response.parse()
            assert_matches_type(AsyncOffsetPagination[StyleGuide], style_guide, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .tags import (
    TagsResource,
    AsyncTagsResource,
    TagsResourceWithRawResponse,
    AsyncTagsResourceWithRawResponse,
    TagsResourceWithStreamingResponse,
    AsyncTagsResourceWithStreamingResponse,
)
from .tasks import (
    TasksResource,
    AsyncTasksResource,
    TasksResourceWithRawResponse,
    AsyncTasksResourceWithRawResponse,
    TasksResourceWithStreamingResponse,
    AsyncTasksResourceWithStreamingResponse,
)

__all__ = [
    "TagsResource",
    "AsyncTagsResource",
    "TagsResourceWithRawResponse",
    "AsyncTagsResourceWithRawResponse",
    "TagsResourceWithStreamingResponse",
    "AsyncTagsResourceWithStreamingResponse",
    "TasksResource",
    "AsyncTasksResource",
    "TasksResourceWithRawResponse",
    "AsyncTasksResourceWithRawResponse",
    "TasksResourceWithStreamingResponse",
    "AsyncTasksResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import (
    EvalType,
    definition_link_params,
    definition_list_params,
    definition_create_params,
    definition_unlink_params,
    definition_update_params,
)
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncOffsetPagination, AsyncOffsetPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.eval_type import EvalType
from ..types.eval_definition import EvalDefinition
from ..types.definition_create_response import DefinitionCreateResponse
from ..types.definition_update_response import DefinitionUpdateResponse

__all__ = ["DefinitionsResource", "AsyncDefinitionsResource"]


class DefinitionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DefinitionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return DefinitionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DefinitionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return DefinitionsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        type: EvalType,
        global_config: definition_create_params.GlobalConfig | Omit = omit,
        style_guide_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DefinitionCreateResponse:
        """
        Creates a new evaluation definition for an application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v0/definitions",
            body=maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "global_config": global_config,
                    "style_guide_id": style_guide_id,
                },
                definition_create_params.DefinitionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DefinitionCreateResponse,
        )

    def update(
        self,
        id: str,
        *,
        global_config: definition_update_params.GlobalConfig | Omit = omit,
        name: str | Omit = omit,
        style_guide_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DefinitionUpdateResponse:
        """
        Updates an existing evaluation definition.

        Args:
          id: The unique identifier of the evaluation definition

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._put(
            f"/v0/definitions/{id}",
            body=maybe_transform(
                {
                    "global_config": global_config,
                    "name": name,
                    "style_guide_id": style_guide_id,
                },
                definition_update_params.DefinitionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DefinitionUpdateResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        skip: int | Omit = omit,
        status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"] | Omit = omit,
        task_id: str | Omit = omit,
        trace_id: str | Omit = omit,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncOffsetPagination[EvalDefinition]:
        """
        Retrieves a paginated list of evaluation definitions for an application.

        Args:
          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          skip: Number of items to skip before starting to collect the result set.

          status: Filter by evaluation status (e.g. COMPLETED)

          task_id: Filter by task ID

          trace_id: Filter by trace ID

          type: Filter by evaluation type (e.g. NATURALNESS)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/definitions",
            page=SyncOffsetPagination[EvalDefinition],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "skip": skip,
                        "status": status,
                        "task_id": task_id,
                        "trace_id": trace_id,
                        "type": type,
                    },
                    definition_list_params.DefinitionListParams,
                ),
            ),
            model=EvalDefinition,
        )

    def link(
        self,
        *,
        eval_ids: SequenceNotStr[str],
        task_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Associates an evaluation definition with a task for automatic evaluation.

        Args:
          eval_ids: Array of evaluation definition IDs to link/unlink. Can be a single ID or
              multiple IDs.

          task_ids: Array of task IDs to link/unlink the evaluation definitions to/from. Can be a
              single ID or multiple IDs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/definitions/link",
            body=maybe_transform(
                {
                    "eval_ids": eval_ids,
                    "task_ids": task_ids,
                },
                definition_link_params.DefinitionLinkParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def unlink(
        self,
        *,
        eval_ids: SequenceNotStr[str],
        task_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Removes the association between an evaluation definition and a task.

        Args:
          eval_ids: Array of evaluation definition IDs to link/unlink. Can be a single ID or
              multiple IDs.

          task_ids: Array of task IDs to link/unlink the evaluation definitions to/from. Can be a
              single ID or multiple IDs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/definitions/unlink",
            body=maybe_transform(
                {
                    "eval_ids": eval_ids,
                    "task_ids": task_ids,
                },
                definition_unlink_params.DefinitionUnlinkParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncDefinitionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDefinitionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncDefinitionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDefinitionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncDefinitionsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        type: EvalType,
        global_config: definition_create_params.GlobalConfig | Omit = omit,
        style_guide_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DefinitionCreateResponse:
        """
        Creates a new evaluation definition for an application.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v0/definitions",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "type": type,
                    "global_config": global_config,
                    "style_guide_id": style_guide_id,
                },
                definition_create_params.DefinitionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DefinitionCreateResponse,
        )

    async def update(
        self,
        id: str,
        *,
        global_config: definition_update_params.GlobalConfig | Omit = omit,
        name: str | Omit = omit,
        style_guide_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DefinitionUpdateResponse:
        """
        Updates an existing evaluation definition.

        Args:
          id: The unique identifier of the evaluation definition

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._put(
            f"/v0/definitions/{id}",
            body=await async_maybe_transform(
                {
                    "global_config": global_config,
                    "name": name,
                    "style_guide_id": style_guide_id,
                },
                definition_update_params.DefinitionUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DefinitionUpdateResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        skip: int | Omit = omit,
        status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"] | Omit = omit,
        task_id: str | Omit = omit,
        trace_id: str | Omit = omit,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[EvalDefinition, AsyncOffsetPagination[EvalDefinition]]:
        """
        Retrieves a paginated list of evaluation definitions for an application.

        Args:
          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          skip: Number of items to skip before starting to collect the result set.

          status: Filter by evaluation status (e.g. COMPLETED)

          task_id: Filter by task ID

          trace_id: Filter by trace ID

          type: Filter by evaluation type (e.g. NATURALNESS)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/definitions",
            page=AsyncOffsetPagination[EvalDefinition],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "skip": skip,
                        "status": status,
                        "task_id": task_id,
                        "trace_id": trace_id,
                        "type": type,
                    },
                    definition_list_params.DefinitionListParams,
                ),
            ),
            model=EvalDefinition,
        )

    async def link(
        self,
        *,
        eval_ids: SequenceNotStr[str],
        task_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Associates an evaluation definition with a task for automatic evaluation.

        Args:
          eval_ids: Array of evaluation definition IDs to link/unlink. Can be a single ID or
              multiple IDs.

          task_ids: Array of task IDs to link/unlink the evaluation definitions to/from. Can be a
              single ID or multiple IDs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/definitions/link",
            body=await async_maybe_transform(
                {
                    "eval_ids": eval_ids,
                    "task_ids": task_ids,
                },
                definition_link_params.DefinitionLinkParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def unlink(
        self,
        *,
        eval_ids: SequenceNotStr[str],
        task_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Removes the association between an evaluation definition and a task.

        Args:
          eval_ids: Array of evaluation definition IDs to link/unlink. Can be a single ID or
              multiple IDs.

          task_ids: Array of task IDs to link/unlink the evaluation definitions to/from. Can be a
              single ID or multiple IDs.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/definitions/unlink",
            body=await async_maybe_transform(
                {
                    "eval_ids": eval_ids,
                    "task_ids": task_ids,
                },
                definition_unlink_params.DefinitionUnlinkParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class DefinitionsResourceWithRawResponse:
    def __init__(self, definitions: DefinitionsResource) -> None:
        self._definitions = definitions

        self.create = to_raw_response_wrapper(
            definitions.create,
        )
        self.update = to_raw_response_wrapper(
            definitions.update,
        )
        self.list = to_raw_response_wrapper(
            definitions.list,
        )
        self.link = to_raw_response_wrapper(
            definitions.link,
        )
        self.unlink = to_raw_response_wrapper(
            definitions.unlink,
        )


class AsyncDefinitionsResourceWithRawResponse:
    def __init__(self, definitions: AsyncDefinitionsResource) -> None:
        self._definitions = definitions

        self.create = async_to_raw_response_wrapper(
            definitions.create,
        )
        self.update = async_to_raw_response_wrapper(
            definitions.update,
        )
        self.list = async_to_raw_response_wrapper(
            definitions.list,
        )
        self.link = async_to_raw_response_wrapper(
            definitions.link,
        )
        self.unlink = async_to_raw_response_wrapper(
            definitions.unlink,
        )


class DefinitionsResourceWithStreamingResponse:
    def __init__(self, definitions: DefinitionsResource) -> None:
        self._definitions = definitions

        self.create = to_streamed_response_wrapper(
            definitions.create,
        )
        self.update = to_streamed_response_wrapper(
            definitions.update,
        )
        self.list = to_streamed_response_wrapper(
            definitions.list,
        )
        self.link = to_streamed_response_wrapper(
            definitions.link,
        )
        self.unlink = to_streamed_response_wrapper(
            definitions.unlink,
        )


class AsyncDefinitionsResourceWithStreamingResponse:
    def __init__(self, definitions: AsyncDefinitionsResource) -> None:
        self._definitions = definitions

        self.create = async_to_streamed_response_wrapper(
            definitions.create,
        )
        self.update = async_to_streamed_response_wrapper(
            definitions.update,
        )
        self.list = async_to_streamed_response_wrapper(
            definitions.list,
        )
        self.link = async_to_streamed_response_wrapper(
            definitions.link,
        )
        self.unlink = async_to_streamed_response_wrapper(
            definitions.unlink,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestIssues:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        issue = client.issues.create(
            source="TEST",
            title="Response quality degradation",
        )
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Avido) -> None:
        issue = client.issues.create(
            source="TEST",
            title="Response quality degradation",
            annotation_id="890e5678-e89b-12d3-a456-426614174000",
            description="The chatbot is providing incomplete responses to user queries",
            eval_definition_id="789e4567-e89b-12d3-a456-426614174000",
            experiment_id="789e4567-e89b-12d3-a456-426614174000",
            parent_id="123e4567-e89b-12d3-a456-426614174000",
            priority="HIGH",
            task_id="789e4567-e89b-12d3-a456-426614174000",
            test_id="789e4567-e89b-12d3-a456-426614174000",
            topic_id="789e4567-e89b-12d3-a456-426614174000",
            trace_id="trace_abc123",
            type="BUG",
        )
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.issues.with_raw_response.create(
            source="TEST",
            title="Response quality degradation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        issue = response.parse()
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.issues.with_streaming_response.create(
            source="TEST",
            title="Response quality degradation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            issue = response.parse()
            assert issue is None

        assert cast(Any, response.is_closed) is True


class TestAsyncIssues:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        issue = await async_client.issues.create(
            source="TEST",
            title="Response quality degradation",
        )
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAvido) -> None:
        issue = await async_client.issues.create(
            source="TEST",
            title="Response quality degradation",
            annotation_id="890e5678-e89b-12d3-a456-426614174000",
            description="The chatbot is providing incomplete responses to user queries",
            eval_definition_id="789e4567-e89b-12d3-a456-426614174000",
            experiment_id="789e4567-e89b-12d3-a456-426614174000",
            parent_id="123e4567-e89b-12d3-a456-426614174000",
            priority="HIGH",
            task_id="789e4567-e89b-12d3-a456-426614174000",
            test_id="789e4567-e89b-12d3-a456-426614174000",
            topic_id="789e4567-e89b-12d3-a456-426614174000",
            trace_id="trace_abc123",
            type="BUG",
        )
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.issues.with_raw_response.create(
            source="TEST",
            title="Response quality degradation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        issue = await response.parse()
        assert issue is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.issues.with_streaming_response.create(
            source="TEST",
            title="Response quality degradation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            issue = await response.parse()
            assert issue is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["UsageParam"]


class UsageParam(TypedDict, total=False):
    completion_tokens: Required[Annotated[int, PropertyInfo(alias="completionTokens")]]
    """Number of completion tokens used by the LLM."""

    prompt_tokens: Required[Annotated[int, PropertyInfo(alias="promptTokens")]]
    """Number of prompt tokens used by the LLM."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["TaskTriggerParams"]


class TaskTriggerParams(TypedDict, total=False):
    task_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="taskIds")]]
    """Array of task IDs to trigger"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .topic import Topic
from .._models import BaseModel

__all__ = ["TopicCreateResponse"]


class TopicCreateResponse(BaseModel):
    """Successful response containing the topic data"""

    data: Topic
    """Details about a single Topic"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .run_type import RunType
from .test_result import TestResult
from .eval_definition import EvalDefinition

__all__ = [
    "TestListResponse",
    "Eval",
    "EvalResults",
    "EvalResultsUnionMember0",
    "EvalResultsUnionMember1",
    "EvalResultsUnionMember2",
    "EvalResultsUnionMember2AnswerRelevancy",
    "EvalResultsUnionMember2AnswerRelevancyMetadata",
    "EvalResultsUnionMember2AnswerRelevancyMetadataQuestion",
    "EvalResultsUnionMember2AnswerRelevancyMetadataSimilarity",
    "EvalResultsUnionMember2ContextPrecision",
    "EvalResultsUnionMember2ContextPrecisionMetadata",
    "EvalResultsUnionMember2ContextRelevancy",
    "EvalResultsUnionMember2ContextRelevancyMetadata",
    "EvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence",
    "EvalResultsUnionMember2Faithfulness",
    "EvalResultsUnionMember2FaithfulnessMetadata",
    "EvalResultsUnionMember2FaithfulnessMetadataFaithfulness",
    "EvalResultsUnionMember3",
    "EvalResultsUnionMember3Metadata",
    "EvalResultsUnionMember4",
    "EvalResultsUnionMember4Classification",
    "EvalResultsUnionMember5",
    "EvalResultsUnionMember5Missing",
    "Task",
]


class EvalResultsUnionMember0(BaseModel):
    analysis: str

    clarity: float

    coherence: float

    engagingness: float

    naturalness: float

    relevance: float


class EvalResultsUnionMember1(BaseModel):
    analysis: str
    """
    A brief explanation for your rating, referring to specific aspects of the
    response and the query. Make sure that the explanation is formatted as markdown,
    and that it is easy to read and understand.
    """

    score: float
    """The score of the response based on the style guide from 1-5"""


class EvalResultsUnionMember2AnswerRelevancyMetadataQuestion(BaseModel):
    question: str


class EvalResultsUnionMember2AnswerRelevancyMetadataSimilarity(BaseModel):
    question: str

    score: float


class EvalResultsUnionMember2AnswerRelevancyMetadata(BaseModel):
    questions: List[EvalResultsUnionMember2AnswerRelevancyMetadataQuestion]

    similarity: List[EvalResultsUnionMember2AnswerRelevancyMetadataSimilarity]


class EvalResultsUnionMember2AnswerRelevancy(BaseModel):
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[EvalResultsUnionMember2AnswerRelevancyMetadata] = None


class EvalResultsUnionMember2ContextPrecisionMetadata(BaseModel):
    reason: str

    verdict: int


class EvalResultsUnionMember2ContextPrecision(BaseModel):
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[EvalResultsUnionMember2ContextPrecisionMetadata] = None


class EvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence(BaseModel):
    reasons: List[str]

    sentence: str


class EvalResultsUnionMember2ContextRelevancyMetadata(BaseModel):
    relevant_sentences: List[EvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence] = FieldInfo(
        alias="relevantSentences"
    )


class EvalResultsUnionMember2ContextRelevancy(BaseModel):
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[EvalResultsUnionMember2ContextRelevancyMetadata] = None


class EvalResultsUnionMember2FaithfulnessMetadataFaithfulness(BaseModel):
    reason: str

    statement: str

    verdict: int

    classification: Optional[Literal["UNSUPPORTED_CLAIM", "CONTRADICTION", "PARTIAL_HALLUCINATION", "SCOPE_DRIFT"]] = (
        None
    )
    """Classification of the hallucination type (only present when verdict is 0)"""


class EvalResultsUnionMember2FaithfulnessMetadata(BaseModel):
    faithfulness: List[EvalResultsUnionMember2FaithfulnessMetadataFaithfulness]

    statements: List[str]


class EvalResultsUnionMember2Faithfulness(BaseModel):
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[EvalResultsUnionMember2FaithfulnessMetadata] = None


class EvalResultsUnionMember2(BaseModel):
    answer_relevancy: EvalResultsUnionMember2AnswerRelevancy = FieldInfo(alias="AnswerRelevancy")

    context_precision: EvalResultsUnionMember2ContextPrecision = FieldInfo(alias="ContextPrecision")

    context_relevancy: EvalResultsUnionMember2ContextRelevancy = FieldInfo(alias="ContextRelevancy")

    faithfulness: EvalResultsUnionMember2Faithfulness = FieldInfo(alias="Faithfulness")


class EvalResultsUnionMember3Metadata(BaseModel):
    rationale: str


class EvalResultsUnionMember3(BaseModel):
    name: str

    score: int

    error: Optional[str] = None

    metadata: Optional[EvalResultsUnionMember3Metadata] = None


class EvalResultsUnionMember4Classification(BaseModel):
    fn: List[str] = FieldInfo(alias="FN")
    """False negatives: Statements found in the ground truth but omitted in the answer"""

    fp: List[str] = FieldInfo(alias="FP")
    """
    False positives: Statements present in the answer but not found in the ground
    truth
    """

    tp: List[str] = FieldInfo(alias="TP")
    """
    True positives: Statements that are present in both the answer and the ground
    truth
    """


class EvalResultsUnionMember4(BaseModel):
    classification: EvalResultsUnionMember4Classification

    score: float
    """The F1 score of the response based on the fact checker (0-1)"""

    error: Optional[str] = None

    metadata: Optional[object] = None


class EvalResultsUnionMember5Missing(BaseModel):
    have: float

    need: float

    value: str


class EvalResultsUnionMember5(BaseModel):
    reason: str

    score: float

    expected: Optional[str] = None

    expected_list: Optional[List[str]] = FieldInfo(alias="expectedList", default=None)

    f1: Optional[float] = None

    got: Optional[str] = None

    got_list: Optional[List[str]] = FieldInfo(alias="gotList", default=None)

    match_mode: Optional[Literal["exact_unordered", "contains"]] = FieldInfo(alias="matchMode", default=None)

    missing: Optional[List[EvalResultsUnionMember5Missing]] = None

    precision: Optional[float] = None

    recall: Optional[float] = None

    score_metric: Optional[Literal["f1", "precision", "recall"]] = FieldInfo(alias="scoreMetric", default=None)

    tp: Optional[float] = None


EvalResults: TypeAlias = Union[
    EvalResultsUnionMember0,
    EvalResultsUnionMember1,
    EvalResultsUnionMember2,
    EvalResultsUnionMember3,
    EvalResultsUnionMember4,
    EvalResultsUnionMember5,
]


class Eval(BaseModel):
    """Complete evaluation information"""

    id: str
    """Unique identifier of the evaluation"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the evaluation was created"""

    definition: EvalDefinition

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the evaluation was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this evaluation"""

    status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]
    """Status of the evaluation/test"""

    passed: Optional[bool] = None
    """Whether the evaluation passed"""

    results: Optional[EvalResults] = None
    """Results of the evaluation (structure depends on eval type)."""

    score: Optional[float] = None
    """Overall score of the evaluation"""


class Task(BaseModel):
    id: str
    """The unique identifier of the task"""

    title: str
    """The title of the task"""

    topic_id: Optional[str] = FieldInfo(alias="topicId", default=None)
    """The ID of the topic this task belongs to"""


class TestListResponse(BaseModel):
    __test__ = False
    id: str
    """Unique identifier of the run"""

    application_id: str = FieldInfo(alias="applicationId")
    """The ID of the application this test belongs to"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the test was created"""

    evals: List[Eval]
    """Array of evaluations in this run"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the test was last modified"""

    run_id: str = FieldInfo(alias="runId")
    """The unique identifier of the run"""

    run_type: RunType = FieldInfo(alias="runType")
    """The type of run this test belongs to"""

    status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]
    """Status of the evaluation/test"""

    task: Task

    task_id: str = FieldInfo(alias="taskId")
    """The unique identifier of the task"""

    result: Optional[TestResult] = None
    """Aggregated test result with pass/fail statistics"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Topic"]


class Topic(BaseModel):
    """Details about a single Topic"""

    id: str
    """Unique identifier of the topic"""

    baseline: Optional[float] = None
    """Optional baseline score for this topic"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the topic was created"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the topic was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this topic"""

    title: str
    """Title of the topic"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel
from .style_guide import StyleGuide

__all__ = ["StyleGuideRetrieveResponse"]


class StyleGuideRetrieveResponse(BaseModel):
    """Successful response containing the style guide data"""

    data: StyleGuide
    """A style guide for a specific application"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .test_result import TestResult
from .eval_definition import EvalDefinition

__all__ = [
    "TestRetrieveResponse",
    "Test",
    "TestEval",
    "TestEvalResults",
    "TestEvalResultsUnionMember0",
    "TestEvalResultsUnionMember1",
    "TestEvalResultsUnionMember2",
    "TestEvalResultsUnionMember2AnswerRelevancy",
    "TestEvalResultsUnionMember2AnswerRelevancyMetadata",
    "TestEvalResultsUnionMember2AnswerRelevancyMetadataQuestion",
    "TestEvalResultsUnionMember2AnswerRelevancyMetadataSimilarity",
    "TestEvalResultsUnionMember2ContextPrecision",
    "TestEvalResultsUnionMember2ContextPrecisionMetadata",
    "TestEvalResultsUnionMember2ContextRelevancy",
    "TestEvalResultsUnionMember2ContextRelevancyMetadata",
    "TestEvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence",
    "TestEvalResultsUnionMember2Faithfulness",
    "TestEvalResultsUnionMember2FaithfulnessMetadata",
    "TestEvalResultsUnionMember2FaithfulnessMetadataFaithfulness",
    "TestEvalResultsUnionMember3",
    "TestEvalResultsUnionMember3Metadata",
    "TestEvalResultsUnionMember4",
    "TestEvalResultsUnionMember4Classification",
    "TestEvalResultsUnionMember5",
    "TestEvalResultsUnionMember5Missing",
]


class TestEvalResultsUnionMember0(BaseModel):
    __test__ = False
    analysis: str

    clarity: float

    coherence: float

    engagingness: float

    naturalness: float

    relevance: float


class TestEvalResultsUnionMember1(BaseModel):
    __test__ = False
    analysis: str
    """
    A brief explanation for your rating, referring to specific aspects of the
    response and the query. Make sure that the explanation is formatted as markdown,
    and that it is easy to read and understand.
    """

    score: float
    """The score of the response based on the style guide from 1-5"""


class TestEvalResultsUnionMember2AnswerRelevancyMetadataQuestion(BaseModel):
    __test__ = False
    question: str


class TestEvalResultsUnionMember2AnswerRelevancyMetadataSimilarity(BaseModel):
    __test__ = False
    question: str

    score: float


class TestEvalResultsUnionMember2AnswerRelevancyMetadata(BaseModel):
    __test__ = False
    questions: List[TestEvalResultsUnionMember2AnswerRelevancyMetadataQuestion]

    similarity: List[TestEvalResultsUnionMember2AnswerRelevancyMetadataSimilarity]


class TestEvalResultsUnionMember2AnswerRelevancy(BaseModel):
    __test__ = False
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[TestEvalResultsUnionMember2AnswerRelevancyMetadata] = None


class TestEvalResultsUnionMember2ContextPrecisionMetadata(BaseModel):
    __test__ = False
    reason: str

    verdict: int


class TestEvalResultsUnionMember2ContextPrecision(BaseModel):
    __test__ = False
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[TestEvalResultsUnionMember2ContextPrecisionMetadata] = None


class TestEvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence(BaseModel):
    __test__ = False
    reasons: List[str]

    sentence: str


class TestEvalResultsUnionMember2ContextRelevancyMetadata(BaseModel):
    __test__ = False
    relevant_sentences: List[TestEvalResultsUnionMember2ContextRelevancyMetadataRelevantSentence] = FieldInfo(
        alias="relevantSentences"
    )


class TestEvalResultsUnionMember2ContextRelevancy(BaseModel):
    __test__ = False
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[TestEvalResultsUnionMember2ContextRelevancyMetadata] = None


class TestEvalResultsUnionMember2FaithfulnessMetadataFaithfulness(BaseModel):
    __test__ = False
    reason: str

    statement: str

    verdict: int

    classification: Optional[Literal["UNSUPPORTED_CLAIM", "CONTRADICTION", "PARTIAL_HALLUCINATION", "SCOPE_DRIFT"]] = (
        None
    )
    """Classification of the hallucination type (only present when verdict is 0)"""


class TestEvalResultsUnionMember2FaithfulnessMetadata(BaseModel):
    __test__ = False
    faithfulness: List[TestEvalResultsUnionMember2FaithfulnessMetadataFaithfulness]

    statements: List[str]


class TestEvalResultsUnionMember2Faithfulness(BaseModel):
    __test__ = False
    name: str

    score: float

    error: Optional[str] = None

    metadata: Optional[TestEvalResultsUnionMember2FaithfulnessMetadata] = None


class TestEvalResultsUnionMember2(BaseModel):
    __test__ = False
    answer_relevancy: TestEvalResultsUnionMember2AnswerRelevancy = FieldInfo(alias="AnswerRelevancy")

    context_precision: TestEvalResultsUnionMember2ContextPrecision = FieldInfo(alias="ContextPrecision")

    context_relevancy: TestEvalResultsUnionMember2ContextRelevancy = FieldInfo(alias="ContextRelevancy")

    faithfulness: TestEvalResultsUnionMember2Faithfulness = FieldInfo(alias="Faithfulness")


class TestEvalResultsUnionMember3Metadata(BaseModel):
    __test__ = False
    rationale: str


class TestEvalResultsUnionMember3(BaseModel):
    __test__ = False
    name: str

    score: int

    error: Optional[str] = None

    metadata: Optional[TestEvalResultsUnionMember3Metadata] = None


class TestEvalResultsUnionMember4Classification(BaseModel):
    __test__ = False
    fn: List[str] = FieldInfo(alias="FN")
    """False negatives: Statements found in the ground truth but omitted in the answer"""

    fp: List[str] = FieldInfo(alias="FP")
    """
    False positives: Statements present in the answer but not found in the ground
    truth
    """

    tp: List[str] = FieldInfo(alias="TP")
    """
    True positives: Statements that are present in both the answer and the ground
    truth
    """


class TestEvalResultsUnionMember4(BaseModel):
    __test__ = False
    classification: TestEvalResultsUnionMember4Classification

    score: float
    """The F1 score of the response based on the fact checker (0-1)"""

    error: Optional[str] = None

    metadata: Optional[object] = None


class TestEvalResultsUnionMember5Missing(BaseModel):
    __test__ = False
    have: float

    need: float

    value: str


class TestEvalResultsUnionMember5(BaseModel):
    __test__ = False
    reason: str

    score: float

    expected: Optional[str] = None

    expected_list: Optional[List[str]] = FieldInfo(alias="expectedList", default=None)

    f1: Optional[float] = None

    got: Optional[str] = None

    got_list: Optional[List[str]] = FieldInfo(alias="gotList", default=None)

    match_mode: Optional[Literal["exact_unordered", "contains"]] = FieldInfo(alias="matchMode", default=None)

    missing: Optional[List[TestEvalResultsUnionMember5Missing]] = None

    precision: Optional[float] = None

    recall: Optional[float] = None

    score_metric: Optional[Literal["f1", "precision", "recall"]] = FieldInfo(alias="scoreMetric", default=None)

    tp: Optional[float] = None


TestEvalResults: TypeAlias = Union[
    TestEvalResultsUnionMember0,
    TestEvalResultsUnionMember1,
    TestEvalResultsUnionMember2,
    TestEvalResultsUnionMember3,
    TestEvalResultsUnionMember4,
    TestEvalResultsUnionMember5,
]


class TestEval(BaseModel):
    __test__ = False
    """Complete evaluation information"""
    id: str
    """Unique identifier of the evaluation"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the evaluation was created"""

    definition: EvalDefinition

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the evaluation was last modified"""

    org_id: str = FieldInfo(alias="orgId")
    """Organization ID that owns this evaluation"""

    status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]
    """Status of the evaluation/test"""

    passed: Optional[bool] = None
    """Whether the evaluation passed"""

    results: Optional[TestEvalResults] = None
    """Results of the evaluation (structure depends on eval type)."""

    score: Optional[float] = None
    """Overall score of the evaluation"""


class Test(BaseModel):
    __test__ = False
    """A Test represents a single test applying all the linked evals on a Trace"""
    id: str
    """Unique identifier of the run"""

    application_id: str = FieldInfo(alias="applicationId")
    """The ID of the application this test belongs to"""

    created_at: datetime = FieldInfo(alias="createdAt")
    """When the test was created"""

    evals: List[TestEval]
    """Array of evaluations in this run"""

    modified_at: datetime = FieldInfo(alias="modifiedAt")
    """When the test was last modified"""

    run_id: str = FieldInfo(alias="runId")
    """The unique identifier of the run"""

    status: Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]
    """Status of the evaluation/test"""

    task_id: str = FieldInfo(alias="taskId")
    """The unique identifier of the task"""

    result: Optional[TestResult] = None
    """Aggregated test result with pass/fail statistics"""


class TestRetrieveResponse(BaseModel):
    __test__ = False
    test: Test
    """A Test represents a single test applying all the linked evals on a Trace"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import ValidateWebhookValidateResponse
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestValidateWebhook:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_validate(self, client: Avido) -> None:
        validate_webhook = client.validate_webhook.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_validate_with_all_params(self, client: Avido) -> None:
        validate_webhook = client.validate_webhook.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
                "experiment": {
                    "experiment_id": "123e4567-e89b-12d3-a456-426614174000",
                    "experiment_variant_id": "123e4567-e89b-12d3-a456-426614174000",
                    "overrides": {
                        "foo": {
                            "temperature": "bar",
                            "system": "bar",
                        }
                    },
                },
                "metadata": {
                    "customerId": "bar",
                    "priority": "bar",
                },
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_validate(self, client: Avido) -> None:
        response = client.validate_webhook.with_raw_response.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        validate_webhook = response.parse()
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_validate(self, client: Avido) -> None:
        with client.validate_webhook.with_streaming_response.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            validate_webhook = response.parse()
            assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncValidateWebhook:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_validate(self, async_client: AsyncAvido) -> None:
        validate_webhook = await async_client.validate_webhook.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_validate_with_all_params(self, async_client: AsyncAvido) -> None:
        validate_webhook = await async_client.validate_webhook.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
                "experiment": {
                    "experiment_id": "123e4567-e89b-12d3-a456-426614174000",
                    "experiment_variant_id": "123e4567-e89b-12d3-a456-426614174000",
                    "overrides": {
                        "foo": {
                            "temperature": "bar",
                            "system": "bar",
                        }
                    },
                },
                "metadata": {
                    "customerId": "bar",
                    "priority": "bar",
                },
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_validate(self, async_client: AsyncAvido) -> None:
        response = await async_client.validate_webhook.with_raw_response.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        validate_webhook = await response.parse()
        assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_validate(self, async_client: AsyncAvido) -> None:
        async with async_client.validate_webhook.with_streaming_response.validate(
            body={
                "prompt": "I lost my card, please block it.",
                "test_id": "123e4567-e89b-12d3-a456-426614174000",
            },
            signature="abc123signature",
            timestamp="2024-01-01T00:00:00.000Z",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            validate_webhook = await response.parse()
            assert_matches_type(ValidateWebhookValidateResponse, validate_webhook, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tag_list_response import TagListResponse as TagListResponse
from .tag_update_params import TagUpdateParams as TagUpdateParams
from .tag_update_response import TagUpdateResponse as TagUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .document_version import DocumentVersion as DocumentVersion
from .tag_list_response import TagListResponse as TagListResponse
from .tag_update_params import TagUpdateParams as TagUpdateParams
from .tag_update_response import TagUpdateResponse as TagUpdateResponse
from .version_list_response import VersionListResponse as VersionListResponse
from .version_update_params import VersionUpdateParams as VersionUpdateParams
from .version_create_response import VersionCreateResponse as VersionCreateResponse
from .version_update_response import VersionUpdateResponse as VersionUpdateResponse
from .version_retrieve_response import VersionRetrieveResponse as VersionRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["IssueStatus"]

IssueStatus: TypeAlias = Literal["OPEN", "RESOLVED", "REJECTED"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo
from .run_type import RunType

__all__ = ["TestListParams"]


class TestListParams(TypedDict, total=False):
    pass_rate_statuses: Required[
        Annotated[List[Literal["success", "warning", "error"]], PropertyInfo(alias="passRateStatuses")]
    ]
    """Filter by pass rate status badges (success: >75%, warning: 51-75%, error: ≤50%)"""

    end_date: Annotated[Union[str, datetime], PropertyInfo(alias="endDate", format="iso8601")]
    """Filter eval runs before this date (inclusive)."""

    eval_definition_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="evalDefinitionId")]
    """Filter tests by eval definition ID"""

    experiment_variant_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="experimentVariantId")]
    """Filter tests by experiment variant ID"""

    limit: int
    """Number of items to include in the result set."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Field to order by in the result set."""

    order_dir: Annotated[Literal["asc", "desc"], PropertyInfo(alias="orderDir")]
    """Order direction."""

    run_type: Annotated[List[RunType], PropertyInfo(alias="runType")]
    """Filter tests by run type (MANUAL, SCHEDULED, EXPERIMENT)"""

    skip: int
    """Number of items to skip before starting to collect the result set."""

    start_date: Annotated[Union[str, datetime], PropertyInfo(alias="startDate", format="iso8601")]
    """Filter eval runs after this date (inclusive)."""

    status: List[Literal["PENDING", "IN_PROGRESS", "COMPLETED", "FAILED"]]
    """Filter by test status (e.g. COMPLETED, FAILED)"""

    task_id: Annotated[SequenceNotStr[str], PropertyInfo(alias="taskId")]
    """Filter tests by task ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ..types import application_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncOffsetPagination, AsyncOffsetPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.application import Application
from ..types.application_retrieve_response import ApplicationRetrieveResponse

__all__ = ["ApplicationsResource", "AsyncApplicationsResource"]


class ApplicationsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ApplicationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return ApplicationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ApplicationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return ApplicationsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ApplicationRetrieveResponse:
        """
        Retrieves detailed information about a specific application.

        Args:
          id: The unique identifier of the application

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/v0/applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ApplicationRetrieveResponse,
        )

    def list(
        self,
        *,
        environment: Literal["DEV", "PROD"] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        skip: int | Omit = omit,
        slug: str | Omit = omit,
        type: Literal["CHATBOT", "AGENT"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncOffsetPagination[Application]:
        """
        Retrieves a paginated list of applications with optional filtering.

        Args:
          environment: Filter by application environment

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          skip: Number of items to skip before starting to collect the result set.

          slug: Filter by application slug

          type: Filter by application type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/applications",
            page=SyncOffsetPagination[Application],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "environment": environment,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "skip": skip,
                        "slug": slug,
                        "type": type,
                    },
                    application_list_params.ApplicationListParams,
                ),
            ),
            model=Application,
        )


class AsyncApplicationsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncApplicationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncApplicationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncApplicationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncApplicationsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ApplicationRetrieveResponse:
        """
        Retrieves detailed information about a specific application.

        Args:
          id: The unique identifier of the application

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/v0/applications/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ApplicationRetrieveResponse,
        )

    def list(
        self,
        *,
        environment: Literal["DEV", "PROD"] | Omit = omit,
        limit: int | Omit = omit,
        order_by: str | Omit = omit,
        order_dir: Literal["asc", "desc"] | Omit = omit,
        skip: int | Omit = omit,
        slug: str | Omit = omit,
        type: Literal["CHATBOT", "AGENT"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[Application, AsyncOffsetPagination[Application]]:
        """
        Retrieves a paginated list of applications with optional filtering.

        Args:
          environment: Filter by application environment

          limit: Number of items to include in the result set.

          order_by: Field to order by in the result set.

          order_dir: Order direction.

          skip: Number of items to skip before starting to collect the result set.

          slug: Filter by application slug

          type: Filter by application type

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/v0/applications",
            page=AsyncOffsetPagination[Application],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "environment": environment,
                        "limit": limit,
                        "order_by": order_by,
                        "order_dir": order_dir,
                        "skip": skip,
                        "slug": slug,
                        "type": type,
                    },
                    application_list_params.ApplicationListParams,
                ),
            ),
            model=Application,
        )


class ApplicationsResourceWithRawResponse:
    def __init__(self, applications: ApplicationsResource) -> None:
        self._applications = applications

        self.retrieve = to_raw_response_wrapper(
            applications.retrieve,
        )
        self.list = to_raw_response_wrapper(
            applications.list,
        )


class AsyncApplicationsResourceWithRawResponse:
    def __init__(self, applications: AsyncApplicationsResource) -> None:
        self._applications = applications

        self.retrieve = async_to_raw_response_wrapper(
            applications.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            applications.list,
        )


class ApplicationsResourceWithStreamingResponse:
    def __init__(self, applications: ApplicationsResource) -> None:
        self._applications = applications

        self.retrieve = to_streamed_response_wrapper(
            applications.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            applications.list,
        )


class AsyncApplicationsResourceWithStreamingResponse:
    def __init__(self, applications: AsyncApplicationsResource) -> None:
        self._applications = applications

        self.retrieve = async_to_streamed_response_wrapper(
            applications.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            applications.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import IssueType, IssueSource, IssuePriority, issue_create_params
from .._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.issue_type import IssueType
from ..types.issue_source import IssueSource
from ..types.issue_priority import IssuePriority

__all__ = ["IssuesResource", "AsyncIssuesResource"]


class IssuesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IssuesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return IssuesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IssuesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return IssuesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        source: IssueSource,
        title: str,
        annotation_id: str | Omit = omit,
        description: Optional[str] | Omit = omit,
        eval_definition_id: str | Omit = omit,
        experiment_id: str | Omit = omit,
        parent_id: str | Omit = omit,
        priority: IssuePriority | Omit = omit,
        task_id: str | Omit = omit,
        test_id: str | Omit = omit,
        topic_id: str | Omit = omit,
        trace_id: str | Omit = omit,
        type: IssueType | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Creates a new issue for tracking problems or improvements.

        Args:
          source: Where the issue originated from

          title: Title of the issue

          annotation_id: Associated annotation ID if related to an annotation

          description: Detailed description of the issue

          eval_definition_id: Associated evaluation definition ID if issue came from an evaluation

          experiment_id: Associated experiment ID to link issue to an experiment

          parent_id: Parent issue ID for creating sub-issues

          priority: Priority level of the issue

          task_id: Associated task ID if issue came from a task

          test_id: Associated test ID if issue came from a test

          topic_id: Associated topic ID if issue came from a topic

          trace_id: Associated trace ID for monitoring/debugging

          type: Type/category of the issue

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/v0/issues",
            body=maybe_transform(
                {
                    "source": source,
                    "title": title,
                    "annotation_id": annotation_id,
                    "description": description,
                    "eval_definition_id": eval_definition_id,
                    "experiment_id": experiment_id,
                    "parent_id": parent_id,
                    "priority": priority,
                    "task_id": task_id,
                    "test_id": test_id,
                    "topic_id": topic_id,
                    "trace_id": trace_id,
                    "type": type,
                },
                issue_create_params.IssueCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncIssuesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIssuesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Avido-AI/avido-py#accessing-raw-response-data-eg-headers
        """
        return AsyncIssuesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIssuesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Avido-AI/avido-py#with_streaming_response
        """
        return AsyncIssuesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        source: IssueSource,
        title: str,
        annotation_id: str | Omit = omit,
        description: Optional[str] | Omit = omit,
        eval_definition_id: str | Omit = omit,
        experiment_id: str | Omit = omit,
        parent_id: str | Omit = omit,
        priority: IssuePriority | Omit = omit,
        task_id: str | Omit = omit,
        test_id: str | Omit = omit,
        topic_id: str | Omit = omit,
        trace_id: str | Omit = omit,
        type: IssueType | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Creates a new issue for tracking problems or improvements.

        Args:
          source: Where the issue originated from

          title: Title of the issue

          annotation_id: Associated annotation ID if related to an annotation

          description: Detailed description of the issue

          eval_definition_id: Associated evaluation definition ID if issue came from an evaluation

          experiment_id: Associated experiment ID to link issue to an experiment

          parent_id: Parent issue ID for creating sub-issues

          priority: Priority level of the issue

          task_id: Associated task ID if issue came from a task

          test_id: Associated test ID if issue came from a test

          topic_id: Associated topic ID if issue came from a topic

          trace_id: Associated trace ID for monitoring/debugging

          type: Type/category of the issue

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/v0/issues",
            body=await async_maybe_transform(
                {
                    "source": source,
                    "title": title,
                    "annotation_id": annotation_id,
                    "description": description,
                    "eval_definition_id": eval_definition_id,
                    "experiment_id": experiment_id,
                    "parent_id": parent_id,
                    "priority": priority,
                    "task_id": task_id,
                    "test_id": test_id,
                    "topic_id": topic_id,
                    "trace_id": trace_id,
                    "type": type,
                },
                issue_create_params.IssueCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class IssuesResourceWithRawResponse:
    def __init__(self, issues: IssuesResource) -> None:
        self._issues = issues

        self.create = to_raw_response_wrapper(
            issues.create,
        )


class AsyncIssuesResourceWithRawResponse:
    def __init__(self, issues: AsyncIssuesResource) -> None:
        self._issues = issues

        self.create = async_to_raw_response_wrapper(
            issues.create,
        )


class IssuesResourceWithStreamingResponse:
    def __init__(self, issues: IssuesResource) -> None:
        self._issues = issues

        self.create = to_streamed_response_wrapper(
            issues.create,
        )


class AsyncIssuesResourceWithStreamingResponse:
    def __init__(self, issues: AsyncIssuesResource) -> None:
        self._issues = issues

        self.create = async_to_streamed_response_wrapper(
            issues.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["TaskCreateParams"]


class TaskCreateParams(TypedDict, total=False):
    description: Required[str]
    """A short description of the task"""

    title: Required[str]
    """The title of the task"""

    metadata: Dict[str, object]
    """
    Optional metadata to associate with the task when creating it (e.g., external
    identifiers).
    """

    simulated_prompt_schema: Annotated[Dict[str, object], PropertyInfo(alias="simulatedPromptSchema")]
    """
    JSON schema that defines the structure for user prompts that should be generated
    for tests
    """

    topic_id: Annotated[str, PropertyInfo(alias="topicId")]
    """ID of the topic this task belongs to"""

    type: Literal["STATIC", "NORMAL"]
    """The type of task"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel
from .application import Application

__all__ = ["ApplicationRetrieveResponse"]


class ApplicationRetrieveResponse(BaseModel):
    """Successful response containing the application data"""

    data: Application
    """Application configuration and metadata"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["TagUpdateParams"]


class TagUpdateParams(TypedDict, total=False):
    color: str
    """Hex color code for the tag"""

    description: Optional[str]
    """Optional description of the tag"""

    name: str
    """Name of the tag"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import (
    TaskListResponse,
    TaskCreateResponse,
    TaskUpdateResponse,
    TaskRetrieveResponse,
)
from tests.utils import assert_matches_type
from avido.pagination import SyncOffsetPagination, AsyncOffsetPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTasks:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        task = client.tasks.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Avido) -> None:
        task = client.tasks.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
            metadata={
                "customerId": "bar",
                "priority": "bar",
            },
            simulated_prompt_schema={
                "type": "bar",
                "properties": "bar",
                "required": "bar",
            },
            topic_id="789e4567-e89b-12d3-a456-426614174000",
            type="NORMAL",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.tasks.with_raw_response.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.tasks.with_streaming_response.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(TaskCreateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Avido) -> None:
        task = client.tasks.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskRetrieveResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Avido) -> None:
        response = client.tasks.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(TaskRetrieveResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Avido) -> None:
        with client.tasks.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(TaskRetrieveResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.tasks.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: Avido) -> None:
        task = client.tasks.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Avido) -> None:
        task = client.tasks.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            description="The user wants to block their credit card immediately",
            input_examples=["I need to block my credit card", "Please disable my card"],
            metadata={
                "customerId": "bar",
                "priority": "bar",
            },
            simulated_prompt_schema={
                "type": "bar",
                "properties": "bar",
                "required": "bar",
            },
            title="Updated Credit Card Block",
            topic_id="789e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Avido) -> None:
        response = client.tasks.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Avido) -> None:
        with client.tasks.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(TaskUpdateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.tasks.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Avido) -> None:
        task = client.tasks.list(
            status=["success", "warning"],
        )
        assert_matches_type(SyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Avido) -> None:
        task = client.tasks.list(
            status=["success", "warning"],
            eval_definition_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            search="credit card",
            skip=0,
            tag_id=["string"],
            topic_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert_matches_type(SyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Avido) -> None:
        response = client.tasks.with_raw_response.list(
            status=["success", "warning"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert_matches_type(SyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Avido) -> None:
        with client.tasks.with_streaming_response.list(
            status=["success", "warning"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert_matches_type(SyncOffsetPagination[TaskListResponse], task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_trigger(self, client: Avido) -> None:
        task = client.tasks.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        )
        assert task is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_trigger(self, client: Avido) -> None:
        response = client.tasks.with_raw_response.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = response.parse()
        assert task is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_trigger(self, client: Avido) -> None:
        with client.tasks.with_streaming_response.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = response.parse()
            assert task is None

        assert cast(Any, response.is_closed) is True


class TestAsyncTasks:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
            metadata={
                "customerId": "bar",
                "priority": "bar",
            },
            simulated_prompt_schema={
                "type": "bar",
                "properties": "bar",
                "required": "bar",
            },
            topic_id="789e4567-e89b-12d3-a456-426614174000",
            type="NORMAL",
        )
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.tasks.with_raw_response.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(TaskCreateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.tasks.with_streaming_response.create(
            description="The user wants to block their credit card",
            title="Credit Card Block",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(TaskCreateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskRetrieveResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAvido) -> None:
        response = await async_client.tasks.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(TaskRetrieveResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAvido) -> None:
        async with async_client.tasks.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(TaskRetrieveResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.tasks.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            description="The user wants to block their credit card immediately",
            input_examples=["I need to block my credit card", "Please disable my card"],
            metadata={
                "customerId": "bar",
                "priority": "bar",
            },
            simulated_prompt_schema={
                "type": "bar",
                "properties": "bar",
                "required": "bar",
            },
            title="Updated Credit Card Block",
            topic_id="789e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncAvido) -> None:
        response = await async_client.tasks.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(TaskUpdateResponse, task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncAvido) -> None:
        async with async_client.tasks.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(TaskUpdateResponse, task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.tasks.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.list(
            status=["success", "warning"],
        )
        assert_matches_type(AsyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.list(
            status=["success", "warning"],
            eval_definition_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            search="credit card",
            skip=0,
            tag_id=["string"],
            topic_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert_matches_type(AsyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAvido) -> None:
        response = await async_client.tasks.with_raw_response.list(
            status=["success", "warning"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert_matches_type(AsyncOffsetPagination[TaskListResponse], task, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAvido) -> None:
        async with async_client.tasks.with_streaming_response.list(
            status=["success", "warning"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert_matches_type(AsyncOffsetPagination[TaskListResponse], task, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_trigger(self, async_client: AsyncAvido) -> None:
        task = await async_client.tasks.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        )
        assert task is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_trigger(self, async_client: AsyncAvido) -> None:
        response = await async_client.tasks.with_raw_response.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        task = await response.parse()
        assert task is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_trigger(self, async_client: AsyncAvido) -> None:
        async with async_client.tasks.with_streaming_response.trigger(
            task_ids=["123e4567-e89b-12d3-a456-426614174000", "223e4567-e89b-12d3-a456-426614174001"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            task = await response.parse()
            assert task is None

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import (
    DocumentListResponse,
    DocumentCreateResponse,
    DocumentActivateResponse,
    DocumentRetrieveResponse,
)
from tests.utils import assert_matches_type
from avido._utils import parse_datetime
from avido.pagination import SyncOffsetPagination, AsyncOffsetPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDocuments:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        document = client.documents.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        )
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Avido) -> None:
        document = client.documents.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
            assignee="user_123456789",
            language="english",
            metadata={"foo": "bar"},
            original_sentences=["This is the first sentence.", "This is the second sentence."],
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
            status="DRAFT",
        )
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.documents.with_raw_response.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.documents.with_streaming_response.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentCreateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Avido) -> None:
        document = client.documents.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Avido) -> None:
        response = client.documents.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Avido) -> None:
        with client.documents.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Avido) -> None:
        document = client.documents.list()
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Avido) -> None:
        document = client.documents.list(
            assignee="user_123456789",
            end_date=parse_datetime("2024-12-31T23:59:59.999Z"),
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            scrape_job_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            search="API documentation",
            skip=0,
            start_date=parse_datetime("2024-01-01T00:00:00.000Z"),
            status=["APPROVED"],
            tag_id=["string"],
        )
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Avido) -> None:
        response = client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Avido) -> None:
        with client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_activate(self, client: Avido) -> None:
        document = client.documents.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(DocumentActivateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_activate(self, client: Avido) -> None:
        response = client.documents.with_raw_response.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(DocumentActivateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_activate(self, client: Avido) -> None:
        with client.documents.with_streaming_response.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(DocumentActivateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_activate(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.activate(
                version_number=2,
                id="",
            )


class TestAsyncDocuments:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        )
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
            assignee="user_123456789",
            language="english",
            metadata={"foo": "bar"},
            original_sentences=["This is the first sentence.", "This is the second sentence."],
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
            status="DRAFT",
        )
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentCreateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.create(
            content="This document describes the API endpoints...",
            title="API Documentation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentCreateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentRetrieveResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.list()
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.list(
            assignee="user_123456789",
            end_date=parse_datetime("2024-12-31T23:59:59.999Z"),
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            scrape_job_id=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            search="API documentation",
            skip=0,
            start_date=parse_datetime("2024-01-01T00:00:00.000Z"),
            status=["APPROVED"],
            tag_id=["string"],
        )
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_activate(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(DocumentActivateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_activate(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(DocumentActivateResponse, document, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_activate(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.activate(
            version_number=2,
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(DocumentActivateResponse, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_activate(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.activate(
                version_number=2,
                id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["DocumentCreateParams"]


class DocumentCreateParams(TypedDict, total=False):
    content: Required[str]
    """Content of the initial document version"""

    title: Required[str]
    """Title of the initial document version"""

    assignee: str
    """User ID of the person assigned to this document.

    Defaults to the authenticated user if not provided.
    """

    language: str
    """Language of the initial document version"""

    metadata: Dict[str, object]
    """Optional metadata for the initial document version"""

    original_sentences: Annotated[SequenceNotStr[str], PropertyInfo(alias="originalSentences")]
    """Array of original sentences from the source"""

    scrape_job_id: Annotated[str, PropertyInfo(alias="scrapeJobId")]
    """Optional ID of the scrape job that generated this document"""

    status: Literal["DRAFT", "REVIEW", "APPROVED", "ARCHIVED", "ACTIVE"]
    """Status of the initial document version"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["TopicCreateParams"]


class TopicCreateParams(TypedDict, total=False):
    title: Required[str]
    """Title of the topic"""

    baseline: Optional[float]
    """Optional baseline score for this topic"""
